package dao

import (
	"time"
)

type IntelligentLightGroupRelation struct {
	IntelligentLight
	LightStrategy
	LightControl
	TimeCondition
}

type IntelligentLight struct {
	ID           int       `gorm:"primary key" json:"id"`               //编号
	LightID      int       `gorm:"type:int" json:"lightID"`             //照明策略id
	RelationType int       `gorm:"type:int" json:"relationType"`        //关联类型1=灯控，2=灯杆分组
	Rid          int       `gorm:"type:int" json:"rid"`                 //关联外键ID 根据type类型关联至其表
	TenantId     int       `gorm:"type:int" json:"tenantId"`            //租户ID
	CreateTime   time.Time `gorm:"type:datetime" json:"createTime"`     //新增时间
	CreateUser   int64     `gorm:"type:bigint" json:"createUser"`       //新增记录操作用户ID
	UpdateTime   time.Time `gorm:"type:datetime" json:"updateTime"`     //修改时间
	UpdateUser   int64     `gorm:"type:bigint" json:"updateUser"`       //修改用户
	IsDeleted    int       `gorm:"type:int;default 0" json:"isDeleted"` //是否删除 0=未删除,1=删除
}

func (IntelligentLight) TableName() string {
	return "strategy_intelligent_light"
}

func (c *IntelligentLight) BatchGet(ids []int) ([]IntelligentLight, error) {
	var intelligentLights []IntelligentLight
	err := Db.Debug().Model(&c).Where("light_id in ? and is_deleted = 0", ids).Find(&intelligentLights).Error
	return intelligentLights, err
}

func (c *IntelligentLight) GetByRidAndType() ([]IntelligentLight, error) {
	var intelligentLights []IntelligentLight
	db := Db.Debug().Model(&c).Where("relation_type = ? and is_deleted = 0 and tenant_id = ?",
		c.RelationType, c.TenantId)
	if c.Rid > 0 {
		db = db.Where("rid = ?", c.Rid)
	}
	err := db.Find(&intelligentLights).Error
	return intelligentLights, err
}

func (c *IntelligentLight) GetByGroup(searchValue string, current, size,
	groupId int) ([]IntelligentLightGroupRelation, error) {
	var groupRelations []IntelligentLightGroupRelation
	selectStr := "lig.*,con.id,con.name,b.light_name,t.luminance"
	whereStr := "lig.is_deleted = 0 and relation_type = 1 and lig.tenant_id = ? and con.group_id = ?"
	whereValue := []interface{}{c.TenantId, groupId}
	if searchValue != "" {
		whereStr += " and (con.sn like '%?%' or con.name like '%?%')"
		whereValue = append(whereValue, searchValue, searchValue)
	}
	err := Db.Debug().Table("strategy_intelligent_light lig").Select(selectStr).
		Joins("left join device_light_control con ON lig.rid = con.id").
		Joins("left join strategy_light b ON b.id = lig.light_id").
		Joins("left join strategy_time_condition t ON t.light_id = lig.light_id").
		Where(whereStr, whereValue...).Offset(current).Limit(size).
		Order("lig.create_time desc").Scan(&groupRelations).Error
	return groupRelations, err
}
