package dao

import (
	"github.com/jinzhu/gorm"
	"time"
)

type IpBroadcast struct {
	ID               int        `gorm:"primary_key" json:"id"`                            //编号
	CastName         string     `gorm:"type:varchar(64)" json:"castName"`                 //设备名称
	CastSN           string     `gorm:"type:varchar(60)" json:"castSN"`                   //设备序列号
	LampPoleId       int        `gorm:"type:int" json:"LampPoleId"`                       //所属灯杆id
	LampPoleSN       string     `gorm:"type:varchar(64)" json:"lampPoleSN"`               //所属灯杆sn
	GroupId          int        `gorm:"type:int" json:"groupId"`                          //灯杆分组ID
	GatewayID        int        `gorm:"type:int" json:"gatewayID"`                        //所属网关id
	GatewaySN        string     `gorm:"type:varchar(64)" json:"gatewaySN"`                //所属网关sn
	BrandID          int        `gorm:"type:int" json:"brandID"`                          //设备名称
	ModelID          int        `gorm:"type:int" json:"modelID"`                          //设备型号
	RatedPower       float32    `gorm:"type:float(8, 2); default 0.00" json:"ratedPower"` //额定功率(LED灯)
	IPAddress        string     `gorm:"type:varchar(50)" json:"ipAddress"`                //IP地址
	ServiceIPAddress string     `gorm:"type:varchar(50)" json:"serviceIPAddress"`         //IP地址         //服务IP地址
	ServerPort       int        `gorm:"type:int" json:"serverPort"`                       //服务端口
	SoundVolume      int        `gorm:"type:int" json:"soundVolume"`                      //音量0-100换算
	InstallTime      *time.Time `gorm:"type:date" json:"installTime"`                     //安装时间
	TenantId         int        `gorm:"type:int" json:"tenantId"`                         //租户ID
	CreateTime       time.Time  `gorm:"type:datetime" json:"createTime"`                  //新增时间
	CreateUser       int64      `gorm:"type:bigint" json:"createUser"`                    //新增记录操作用户ID
	UpdateTime       time.Time  `gorm:"type:datetime" json:"updateTime"`                  //修改时间
	UpdateUser       int64      `gorm:"type:bigint" json:"updateUser"`                    //修改用户
	IsDeleted        int        `gorm:"type:int;default 0" json:"isDeleted"`              //是否删除 0=未删除,1=删除
}

func (IpBroadcast) TableName() string {
	return "device_ip_broadcast"
}

func (c IpBroadcast) Delete() error {
	return Db.Debug().Model(&c).Where("id = ?", c.ID).Updates(map[string]interface{}{"update_time": c.UpdateTime,
		"update_user": c.UpdateUser, "is_deleted": c.IsDeleted}).Error
}

func (c IpBroadcast) IsExistedBySN() bool {
	var count = 0
	_ = Db.Debug().Model(&c).Where("  cast_sn = ? and is_deleted = ?",
		c.CastSN, c.IsDeleted).Count(&count).Error
	return count > 0
}

func (c IpBroadcast) IsExistedByNameAndCode() bool {
	var devices []IpBroadcast
	err := Db.Debug().Model(&c).Where(" cast_sn = ? and is_deleted = ?",
		c.CastSN, c.IsDeleted).Find(&devices).Error
	//如果查询不到，返回相应的错误
	if gorm.IsRecordNotFoundError(err) {
		return false
	}
	for _, d := range devices {
		if d.ID != c.ID {
			return true
		}
	}
	return false
}

func (c *IpBroadcast) Create() error {
	return Db.Debug().Model(&c).Save(&c).Error
}

func (c *IpBroadcast) Update() error {
	return Db.Debug().Model(&c).Where(" id = ? ", c.ID).Update(&c).Error
}

func (c *IpBroadcast) GetDevice() error {
	err := Db.Debug().Model(&c).Where(" id = ? ", c.ID).Scan(&c).Error
	return err
}

func (c IpBroadcast) GetDevices(offset, limit int) ([]IpBroadcast, error) {
	var devices []IpBroadcast
	err := Db.Debug().Model(&c).Where(" cast_name like ? ", "%"+c.CastName+"%").Offset(offset).Limit(limit).Find(&devices).Error
	return devices, err
}

func (c IpBroadcast) GetAllDevices() ([]*IpBroadcast, error) {
	var devices []*IpBroadcast
	err := Db.Debug().Model(&c).Where(" tenant_id = ? and is_deleted = ? ", c.TenantId,
		c.IsDeleted).Scan(&devices).Error
	return devices, err
}
